@@ -22,6 +22,10 @@
  * by Wayne Roberts <wroberts1@home.com>. 
  */
 
+
+#include "config.h"
+#include "gnome-vfs-extras-i18n.h"
+
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
@@ -42,6 +46,8 @@
 
 #include <sys/types.h>
 
+#undef PACKAGE
+#undef VERSION
 #include "samba/include/config.h"
 /* don't load crap in "samba/include/includes.h" we don't use and which 
    conflicts with definitions in other includes */
@@ -630,41 +636,51 @@ get_a_master_browser (struct in_addr *ip)
 static char *
 get_root_dir_data (void)
 {
-  return g_strdup ("[Desktop Entry]\n"
-		   "Encoding=Legacy-Mixed\n"
-		   "Name=Network neighborhood\n"
+  return g_strdup_printf ("[Desktop Entry]\n"
+		   "Encoding=UTF-8\n"
+		   "Name=%s\n"
 		   "Type=Directory\n"
-		   "Icon=gnome-computer.png\n");
+		   "Icon=gnome-computer.png\n",
+		   _("Network neighborhood"));
 }
 
 static char *
 get_workgroup_dir_data (const char *name)
 {
-  return g_strdup_printf ("[Desktop Entry]\n"
-			  "Encoding=Legacy-Mixed\n"
-			  "Name=Workgroup %s\n"
+  char *name_field, *retval;
+
+  name_field = g_strdup_printf (_("Workgroup %s"), name);
+  retval = g_strdup_printf ("[Desktop Entry]\n"
+			  "Encoding=UTF-8\n"
+			  "Name=%s\n"
 			  "Type=Directory\n"
 			  "Icon=gnome-computer.png\n",
-			  name);
+			  name_field);
+  g_free (name_field);
+  return retval;
 }
 
 static char *
 get_server_dir_data (const char *name)
 {
-  return g_strdup_printf ("[Desktop Entry]\n"
-			  "Encoding=Legacy-Mixed\n"
-			  "Name=Shares on %s\n"
+  char *name_field, *retval;
+
+  name_field = g_strdup_printf (_("Shares on %s"), name);
+  retval = g_strdup_printf ("[Desktop Entry]\n"
+			  "Encoding=UTF-8\n"
+			  "Name=%s\n"
 			  "Type=Directory\n"
 			  "Icon=gnome-computer.png\n",
-			  name);
+			  name_field);
+  g_free (name_field);
+  return retval;
 }
 
-
 static char *
 get_workgroup_data (const char *name)
 {
   return g_strdup_printf ("[Desktop Entry]\n"
-			  "Encoding=Legacy-Mixed\n"
+			  "Encoding=UTF-8\n"
 			  "Name=%s\n"
 			  "Type=Link\n"
 			  "URL=smb://%s/\n"
@@ -676,7 +692,7 @@ static char *
 get_computer_data (const char *name)
 {
   return g_strdup_printf ("[Desktop Entry]\n"
-			  "Encoding=Legacy-Mixed\n"
+			  "Encoding=UTF-8\n"
 			  "Name=%s\n"
 			  "Type=Link\n"
 			  "URL=smb://%s/\n"
@@ -2458,7 +2474,12 @@ vfs_module_init (const char *method_name, const char *args)
 {
 	TimeInit ();
 	charset_initialise ();
-	
+
+#ifdef ENABLE_NLS
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+#endif
 	if (!lp_load ("/etc/samba/smb.conf", TRUE, FALSE, FALSE)) {
 		DEBUG_SMB (("Couldn't load smb config file"));
 	}
